package com.zhyc.module.base.service;

import java.util.List;
import com.zhyc.module.base.domain.DaRanch;

/**
 * 牧场管理Service接口
 * 
 * @author ruoyi
 * @date 2025-07-22
 */
public interface IDaRanchService 
{
    /**
     * 查询牧场管理
     * 
     * @param id 牧场管理主键
     * @return 牧场管理
     */
    public DaRanch selectDaRanchById(Long id);

    /**
     * 查询牧场管理列表
     * 
     * @param daRanch 牧场管理
     * @return 牧场管理集合
     */
    public List<DaRanch> selectDaRanchList(DaRanch daRanch);

    /**
     * 新增牧场管理
     * 
     * @param daRanch 牧场管理
     * @return 结果
     */
    public int insertDaRanch(DaRanch daRanch);

    /**
     * 修改牧场管理
     * 
     * @param daRanch 牧场管理
     * @return 结果
     */
    public int updateDaRanch(DaRanch daRanch);

    /**
     * 批量删除牧场管理
     * 
     * @param ids 需要删除的牧场管理主键集合
     * @return 结果
     */
    public int deleteDaRanchByIds(Long[] ids);

    /**
     * 删除牧场管理信息
     * 
     * @param id 牧场管理主键
     * @return 结果
     */
    public int deleteDaRanchById(Long id);
}
